# Table of Contents

- [configuring-sso-with-active-directory-federation-services](<./configuring-sso-with-active-directory-federation-services.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Configuring SSO with Active Directory Federation Services](<./Configuring-SSO-with-Active-Directory-Federation-Services.md>)
  - [Prerequisites](<./Configuring-SSO-with-Active-Directory-Federation-Services/Prerequisites.md>)
  - [Configuring SSO](<./Configuring-SSO-with-Active-Directory-Federation-Services/Configuring-SSO.md>)
  - [Configuring Attribute Mapping](<./Configuring-SSO-with-Active-Directory-Federation-Services/Configuring-Attribute-Mapping.md>)
